#
# spec file for package ghc-hasty-hamiltonian
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hasty-hamiltonian
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.0
Release:        lp150.8.1
Summary:        Speedy traversal through parameter space
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-kan-extensions-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-mcmc-types-devel
BuildRequires:  ghc-mwc-probability-devel
BuildRequires:  ghc-pipes-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-ad-devel
%endif

%description
Gradient-based traversal through parameter space.

This implementation of HMC algorithm uses 'lens' as a means to operate over
generic indexed traversable functors, so you can expect it to work if your
target function takes a list, vector, map, sequence, etc. as its argument.

If you don't want to calculate your gradients by hand you can use the handy
<https://hackage.haskell.org/package/ad ad> library for automatic
differentiation.

Exports a 'mcmc' function that prints a trace to stdout, a 'chain' function for
collecting results in memory, and a 'hamiltonian' transition operator that can
be used more generally.

> import Numeric.AD (grad) > import Numeric.MCMC.Hamiltonian > > target ::
RealFloat a => [a] -> a > target [x0, x1] = negate ((x0 + 2 * x1 - 7) ^ 2 + (2
* x0 + x1 - 5) ^ 2) > > gTarget :: [Double] -> [Double] > gTarget = grad target
> > booth :: Target [Double] > booth = Target target (Just gTarget) > > main ::
IO () > main = withSystemRandom . asGenIO $ mcmc 10000 0.05 20 [0, 0] booth.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.3.0 with cabal2obs.
* Fri Dec 16 2016 psimons@suse.com
- Update to version 1.1.5 with cabal2obs.
* Tue Nov  1 2016 psimons@suse.com
- Update to version 1.1.4 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.1.3 revision 0 with cabal2obs.
